@@ -29,8 +29,9 @@ static bool compare(const char *a, const char *b)
 static bool compare(const uint16_t *a, const uint16_t *b)
 {
     while (*a && *b) {
-        if (*a++ != *b++)
+        if (*a++ != *b++) {
             return false;
+        }
     }
     return *a == *b;
 }
@@ -38,8 +39,9 @@ static bool compare(const uint16_t *a, const uint16_t *b)
 static bool compare(const Unicode *a, const char *b, int len)
 {
     for (int i = 0; i < len; i++) {
-        if (a[i] != (Unicode)b[i])
+        if (a[i] != (Unicode)b[i]) {
             return false;
+        }
     }
 
     return true;
@@ -48,8 +50,9 @@ static bool compare(const Unicode *a, const char *b, int len)
 static bool compare(const Unicode *a, const uint16_t *b, int len)
 {
     for (int i = 0; i < len; i++) {
-        if (a[i] != b[i])
+        if (a[i] != b[i]) {
             return false;
+        }
     }
 
     return true;
@@ -89,7 +92,7 @@ void TestUTFConversion::testUTF()
     QCOMPARE(len, s.size()); // QString size() returns number of code units, not code points
     Q_ASSERT(len < (int)sizeof(utf16Buf)); // if this fails, make utf16Buf larger
 
-    len = utf8ToUtf16(str, utf16Buf);
+    len = utf8ToUtf16(str, utf16Buf, sizeof(utf16Buf), INT_MAX);
     QVERIFY(compare(utf16Buf, s.utf16()));
     QCOMPARE(len, s.size());
 
@@ -98,9 +101,9 @@ void TestUTFConversion::testUTF()
     free(utf16String);
 
     std::string sUtf8(str);
-    std::unique_ptr<GooString> gsUtf16_a(utf8ToUtf16WithBom(sUtf8));
+    std::string gsUtf16_a(utf8ToUtf16WithBom(sUtf8));
     std::unique_ptr<GooString> gsUtf16_b(Poppler::QStringToUnicodeGooString(s));
-    QCOMPARE(gsUtf16_a->cmp(gsUtf16_b.get()), 0);
+    QCOMPARE(gsUtf16_b->cmp(gsUtf16_a), 0);
 
     // UTF-16 to UTF-8
 
